@@ -42,6 +42,13 @@ try:
 except ImportError:
     import urlparse
 
+# needed for python2 compatibility
+if sys.version < '3':
+    try:
+        FileNotFoundError
+    except NameError:
+        FileNotFoundError = IOError
+
 import bitcoin
 from bitcoin.core import COIN, x, lx, b2lx, CBlock, CBlockHeader, CTransaction, COutPoint, CTxOut
 from bitcoin.core.script import CScript
@@ -289,7 +296,10 @@ class RawProxy(BaseProxy):
 
     def __getattr__(self, name):
         if name.startswith('__') and name.endswith('__'):
-            # Python internal stuff
+            # Prevent RPC calls for non-existing python internal attribute
+            # access. If someone tries to get an internal attribute
+            # of RawProxy instance, and the instance does not have this
+            # attribute, we do not want the bogus RPC call to happen.
             raise AttributeError
 
         # Create a callable to do the actual call
@@ -371,7 +381,10 @@ class Proxy(BaseProxy):
         return r
 
     def generate(self, numblocks):
-        """Mine blocks immediately (before the RPC call returns)
+        """
+        DEPRECATED (will be removed in bitcoin-core v0.19)
+        
+        Mine blocks immediately (before the RPC call returns)
 
         numblocks - How many blocks are generated immediately.
 
@@ -379,6 +392,19 @@ class Proxy(BaseProxy):
         """
         r = self._call('generate', numblocks)
         return (lx(blk_hash) for blk_hash in r)
+    
+    def generatetoaddress(self, numblocks, addr):
+        """Mine blocks immediately (before the RPC call returns) and
+        allocate block reward to passed address. Replaces deprecated 
+        "generate(self,numblocks)" method.
+
+        numblocks - How many blocks are generated immediately.
+        addr     - Address to receive block reward (CBitcoinAddress instance)
+
+        Returns iterable of block hashes generated.
+        """
+        r = self._call('generatetoaddress', numblocks, str(addr))
+        return (lx(blk_hash) for blk_hash in r)
 
     def getaccountaddress(self, account=None):
         """Return the current Bitcoin address for receiving payments to this
@@ -449,6 +475,9 @@ class Proxy(BaseProxy):
             raise TypeError('%s.getblock(): block_hash must be bytes; got %r instance' %
                     (self.__class__.__name__, block_hash.__class__))
         try:
+            # With this change ( https://github.com/bitcoin/bitcoin/commit/96c850c20913b191cff9f66fedbb68812b1a41ea#diff-a0c8f511d90e83aa9b5857e819ced344 ),
+            # bitcoin core's rpc takes 0/1/2 instead of true/false as the 2nd argument which specifies verbosity, since v0.15.0.
+            # The change above is backward-compatible so far; the old "false" is taken as the new "0".
             r = self._call('getblock', block_hash, False)
         except InvalidAddressOrKeyError as ex:
             raise IndexError('%s.getblock(): %s (%d)' %
